@@ -2,4 +2,4 @@
 from typing import Optional, Any
 from pydantic import BaseModel, Field
 class JobStatus(BaseModel): 
-  status: Optional[JobStatus] = Field()
+  status: JobStatus = Field()
