@@ -2,4 +2,4 @@ from GcodeEvent import GcodeEvent
 from typing import Optional, Any
 from pydantic import BaseModel, Field
 class OctoPrintGcode(BaseModel): 
-  gcode: Optional[GcodeEvent] = Field()
+  gcode: GcodeEvent = Field()
